# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/framefinder',
                'doc_host': 'https://Iseratho.github.io',
                'git_url': 'https://github.com/Iseratho/framefinder',
                'lib_path': 'framefinder'},
  'syms': { 'framefinder.core': {'framefinder.core.foo': ('core.html#foo', 'framefinder/core.py')},
            'framefinder.examples': {},
            'framefinder.framedimensions': { 'framefinder.framedimensions.FramingDimensions': ( 'frame_dimensions.html#framingdimensions',
                                                                                                'framefinder/framedimensions.py'),
                                             'framefinder.framedimensions.FramingDimensions.__call__': ( 'frame_dimensions.html#__call__',
                                                                                                         'framefinder/framedimensions.py'),
                                             'framefinder.framedimensions.FramingDimensions.__init__': ( 'frame_dimensions.html#__init__',
                                                                                                         'framefinder/framedimensions.py'),
                                             'framefinder.framedimensions.FramingDimensions.get_dimension_names': ( 'frame_dimensions.html#get_dimension_names',
                                                                                                                    'framefinder/framedimensions.py'),
                                             'framefinder.framedimensions.FramingDimensions.visualize': ( 'frame_dimensions.html#visualize',
                                                                                                          'framefinder/framedimensions.py')},
            'framefinder.framelabels': { 'framefinder.framelabels.FramingLabels': ( 'frame_labels.html#framinglabels',
                                                                                    'framefinder/framelabels.py'),
                                         'framefinder.framelabels.FramingLabels.__call__': ( 'frame_labels.html#__call__',
                                                                                             'framefinder/framelabels.py'),
                                         'framefinder.framelabels.FramingLabels.__init__': ( 'frame_labels.html#__init__',
                                                                                             'framefinder/framelabels.py'),
                                         'framefinder.framelabels.FramingLabels.get_label_names': ( 'frame_labels.html#get_label_names',
                                                                                                    'framefinder/framelabels.py'),
                                         'framefinder.framelabels.FramingLabels.get_ordered_scores': ( 'frame_labels.html#get_ordered_scores',
                                                                                                       'framefinder/framelabels.py'),
                                         'framefinder.framelabels.FramingLabels.order_scores': ( 'frame_labels.html#order_scores',
                                                                                                 'framefinder/framelabels.py'),
                                         'framefinder.framelabels.FramingLabels.visualize': ( 'frame_labels.html#visualize',
                                                                                              'framefinder/framelabels.py')},
            'framefinder.framestructure': { 'framefinder.framestructure.FramingStructure': ( 'frame_structure.html#framingstructure',
                                                                                             'framefinder/framestructure.py'),
                                            'framefinder.framestructure.FramingStructure.__call__': ( 'frame_structure.html#__call__',
                                                                                                      'framefinder/framestructure.py'),
                                            'framefinder.framestructure.FramingStructure.__init__': ( 'frame_structure.html#__init__',
                                                                                                      'framefinder/framestructure.py'),
                                            'framefinder.framestructure.FramingStructure.visualize': ( 'frame_structure.html#visualize',
                                                                                                       'framefinder/framestructure.py')}}}